==> rsvp-pro-plugin.4.2.5.zip: rsvp-pro-plugin/includes/admin/admin_options/admin_options_form.inc.php <==
<table class="form-table">
	<tbody>
	<tr>
		<th scope="row">
			<label for="attendee_list_columns">
				<?php echo rsvp_pro_get_admin_string( 'settings_attendee_list_columns_label' ); ?>:
			</label>
		</th>
		<td>
			<fieldset>
				<label><input type="checkbox" name="alc_attendee_name"
							  value="Y" <?php echo( in_array( 'attendee_name', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'attendee_name_column_option' );
													?>
					</label><br/>
				<label><input type="checkbox" name="alc_rsvp_status"
							  value="Y" <?php echo( in_array( 'rsvp_status', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'rsvp_status_column_option' );
													?>
					</label><br/>
				<label><input type="checkbox" name="alc_rsvp_date"
							  value="Y" <?php echo( in_array( 'rsvp_date', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'rsvp_date_column_option' );
													?>
					</label><br/>
				<label><input type="checkbox" name="alc_additional_attendee"
							  value="Y" <?php echo( in_array( 'additional_attendee', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'additional_attendee_column_option' );
													?>
					</label><br/>
				<label><input type="checkbox" name="alc_note"
							  value="Y" <?php echo( in_array( 'note', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'note_column_option' );
													?>
					</label><br/>
				<label><input type="checkbox" name="alc_associated_attendees"
							  value="Y" <?php echo( in_array( 'associated_attendees', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'associated_attendees_column_option' );
													?>
					</label><br/>
				<label><input type="checkbox" name="alc_email"
							  value="Y" <?php echo( in_array( 'email', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'email_column_option' );
													?>
					</label><br/>
				<label><input type="checkbox" name="alc_checked_in"
							  value="Y" <?php echo( in_array( 'checked_in', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'checked_in_column_option' );
													?>
					</label><br/>
				<label><input type="checkbox" name="alc_passcode"
							  value="Y" <?php echo( in_array( 'passcode', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'passcode_column_option' );
													?>
					</label><br/>

				<?php
				$sql       = 'SELECT id, question FROM ' . PRO_QUESTIONS_TABLE . ' WHERE rsvpEventID = %d';
				$questions = $wpdb->get_results( $wpdb->prepare( $sql, $eventID ) );
				foreach ( $questions as $q ) {
					?>
					<label><input type="checkbox" name="alc_custom_question_<?php echo $q->id; ?>"
								  value="Y" <?php echo( in_array( 'custom_question_' . $q->id, $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
														<?php
														echo esc_html( stripslashes( $q->question ) );
														?>
						</label><br/>
					<?php
				}
				?>
			</fieldset>
			<br/>
			<span class="description"><?php echo rsvp_pro_get_admin_string( 'settings_attendee_list_columns_description' ); ?></span>
		</td>
	</tr>
	</tbody>
</table>

==> rsvp-pro-plugin-4.4.14.zip: rsvp-pro-plugin/includes/admin/admin_options/admin_options_form.inc.php <==
<table class="form-table">
	<tbody>
	<tr>
		<th scope="row">
			<label for="attendee_list_columns">
				<?php echo rsvp_pro_get_admin_string( 'settings_attendee_list_columns_label' ); ?>:
			</label>
		</th>
		<td>
			<fieldset>
				<label><input type="checkbox" name="alc_attendee_name"
							  value="Y" <?php echo( in_array( 'attendee_name', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'attendee_name_column_option' );
													?>
					</label><br/>
				<label><input type="checkbox" name="alc_rsvp_status"
							  value="Y" <?php echo( in_array( 'rsvp_status', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'rsvp_status_column_option' );
													?>
					</label><br/>
				<label><input type="checkbox" name="alc_rsvp_date"
							  value="Y" <?php echo( in_array( 'rsvp_date', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'rsvp_date_column_option' );
													?>
					</label><br/>
				<label><input type="checkbox" name="alc_additional_attendee"
							  value="Y" <?php echo( in_array( 'additional_attendee', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'additional_attendee_column_option' );
													?>
					</label><br/>
				<label><input type="checkbox" name="alc_note"
							  value="Y" <?php echo( in_array( 'note', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'note_column_option' );
													?>
					</label><br/>
				<label><input type="checkbox" name="alc_associated_attendees"
							  value="Y" <?php echo( in_array( 'associated_attendees', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'associated_attendees_column_option' );
													?>
					</label><br/>
				<label><input type="checkbox" name="alc_email"
							  value="Y" <?php echo( in_array( 'email', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'email_column_option' );
													?>
					</label><br/>
				<label><input type="checkbox" name="alc_checked_in"
							  value="Y" <?php echo( in_array( 'checked_in', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'checked_in_column_option' );
													?>
					</label><br/>
				<label><input type="checkbox" name="alc_passcode"
							  value="Y" <?php echo( in_array( 'passcode', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'passcode_column_option' );
													?>
					</label><br/>
				<label><input type="checkbox" name="alc_alternate_passcode"
							  value="Y" <?php echo( in_array( 'alternate_passcode', $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
													<?php
													echo rsvp_pro_get_admin_string( 'alternate_passcode_label' );
													?>
					</label><br/>

				<?php
				$sql       = 'SELECT id, question FROM ' . PRO_QUESTIONS_TABLE . ' WHERE rsvpEventID = %d';
				$questions = $wpdb->get_results( $wpdb->prepare( $sql, $eventID ) );
				foreach ( $questions as $q ) {
					?>
					<label><input type="checkbox" name="alc_custom_question_<?php echo $q->id; ?>"
								  value="Y" <?php echo( in_array( 'custom_question_' . $q->id, $attendee_list_columns ) ? ' checked="checked"' : '' ); ?> />
														<?php
														echo esc_html( stripslashes( $q->question ) );
														?>
						</label><br/>
					<?php
				}
				?>
			</fieldset>
			<br/>
			<span class="description"><?php echo rsvp_pro_get_admin_string( 'settings_attendee_list_columns_description' ); ?></span>
		</td>
	</tr>
	</tbody>
</table>
